### Name: invMillsRatio
### Title: Inverse Mill's Ratio of probit models
### Aliases: invMillsRatio
### Keywords: models

### ** Examples

## Wooldridge( 2003 ): example 17.5, page 590
data(Mroz87)
myProbit <- glm( lfp ~ nwifeinc + educ + exper + I( exper^2 ) + age +
   kids5 + kids618, family = binomial( link = "probit" ), data=Mroz87 )
Mroz87$IMR <- invMillsRatio( myProbit )$IMR1
myHeckit <- lm( log( wage ) ~ educ + exper + I( exper^2 ) + IMR,
   data = Mroz87[ Mroz87$lfp == 1, ] )

# using NO labor force participation as endogenous variable
Mroz87$nolfp <- 1 - Mroz87$lfp
myProbit2 <- glm( nolfp ~ nwifeinc + educ + exper + I( exper^2 ) + age +
   kids5 + kids618, family = binomial( link = "probit" ), data=Mroz87 )
all.equal( invMillsRatio( myProbit )$IMR1, invMillsRatio( myProbit2 )$IMR0 )
   # should be true

# example for bivariate probit
## Not run: 
##D library( MASS )
##D library( VGAM, pos = 1e7, warn.conflicts = FALSE )
##D 
##D nObs <- 10000
##D 
##D # error terms (trivariate normal)
##D sigma <- symMatrix( c( 2, 0.7, 1.2, 1, 0.5, 1 ) )
##D myData <- as.data.frame( mvrnorm( nObs, c( 0, 0, 0 ), sigma ) )
##D names( myData ) <- c( "e0", "e1", "e2" )
##D 
##D # exogenous variables (indepently normal)
##D myData$x0 <- rnorm( nObs )
##D myData$x1 <- rnorm( nObs )
##D myData$x2 <- rnorm( nObs )
##D 
##D # endogenous variables
##D myData$y0 <-   -1.5 + 0.8 * myData$x1 + myData$e0
##D myData$y1 <- (  0.3 + 0.4 * myData$x1 + 0.3 * myData$x2 + myData$e1 ) > 0
##D myData$y2 <- ( -0.1 + 0.6 * myData$x1 + 0.7 * myData$x2 + myData$e2 ) > 0
##D 
##D # bivariate probit (using rhobit transformation)
##D bProbit <- vglm( cbind( y1, y2 ) ~ x1 + x2, family = binom2.rho,
##D    data = myData )
##D summary( bProbit )
##D 
##D # bivariate probit (NOT using rhobit transformation)
##D bProbit2 <- vglm( cbind( y1, y2 ) ~ x1 + x2, family = binom2.rho(
##D    lrho = "identity" ), data = myData )
##D summary( bProbit2 )
##D 
##D # inverse Mills Ratios
##D imr  <- invMillsRatio( bProbit )
##D imr2 <- invMillsRatio( bProbit2 )
##D all.equal( imr, imr2, tolerance = .Machine$double.eps ^ 0.25)
##D 
##D # tests
##D # E[ e0 | y1* > 0 & y2* > 0 ]
##D mean( myData$e0[ myData$y1 & myData$y2 ] )
##D mean( sigma[1,2] * imr$IMR11a + sigma[1,3] * imr$IMR11b, na.rm = TRUE )
##D # E[ e0 | y1* > 0 & y2* <= 0 ]
##D mean( myData$e0[ myData$y1 & !myData$y2 ] )
##D mean( sigma[1,2] * imr$IMR10a + sigma[1,3] * imr$IMR10b, na.rm = TRUE )
##D # E[ e0 | y1* <= 0 & y2* > 0 ]
##D mean( myData$e0[ !myData$y1 & myData$y2 ] )
##D mean( sigma[1,2] * imr$IMR01a + sigma[1,3] * imr$IMR01b, na.rm = TRUE )
##D # E[ e0 | y1* <= 0 & y2* <= 0 ]
##D mean( myData$e0[ !myData$y1 & !myData$y2 ] )
##D mean( sigma[1,2] * imr$IMR00a + sigma[1,3] * imr$IMR00b, na.rm = TRUE )
##D # E[ e0 | y1* > 0 ]
##D mean( myData$e0[ myData$y1 ] )
##D mean( sigma[1,2] * imr$IMR1X, na.rm = TRUE )
##D # E[ e0 | y1* <= 0 ]
##D mean( myData$e0[ !myData$y1 ] )
##D mean( sigma[1,2] * imr$IMR0X, na.rm = TRUE )
##D # E[ e0 | y2* > 0 ]
##D mean( myData$e0[ myData$y2 ] )
##D mean( sigma[1,3] * imr$IMRX1, na.rm = TRUE )
##D # E[ e0 | y2* <= 0 ]
##D mean( myData$e0[ !myData$y2 ] )
##D mean( sigma[1,3] * imr$IMRX0, na.rm = TRUE )
##D 
##D # estimation for y1* > 0 and y2* > 0
##D selection <- myData$y1 & myData$y2
##D # OLS estimation
##D ols11 <- lm( y0 ~ x1, data = myData, subset = selection )
##D summary( ols11 )
##D # heckman type estimation
##D heckit11 <- lm( y0 ~ x1 + IMR11a + IMR11b, data = cbind( myData, imr ),
##D    subset = selection )
##D summary( heckit11 )
##D 
##D # estimation for y1* > 0 and y2* <= 0
##D selection <- myData$y1 & !myData$y2
##D # OLS estimation
##D ols10 <- lm( y0 ~ x1, data = myData, subset = selection )
##D summary( ols10 )
##D # heckman type estimation
##D heckit10 <- lm( y0 ~ x1 + IMR10a + IMR10b, data = cbind( myData, imr ),
##D    subset = selection )
##D summary( heckit10 )
##D 
##D # estimation for y1* <= 0 and y2* > 0
##D selection <- !myData$y1 & myData$y2
##D # OLS estimation
##D ols01 <- lm( y0 ~ x1, data = myData, subset = selection )
##D summary( ols01 )
##D # heckman type estimation
##D heckit01 <- lm( y0 ~ x1 + IMR01a + IMR01b, data = cbind( myData, imr ),
##D    subset = selection )
##D summary( heckit01 )
##D 
##D # estimation for y1* <= 0 and y2* <= 0
##D selection <- !myData$y1 & !myData$y2
##D # OLS estimation
##D ols00 <- lm( y0 ~ x1, data = myData, subset = selection )
##D summary( ols00 )
##D # heckman type estimation
##D heckit00 <- lm( y0 ~ x1 + IMR00a + IMR00b, data = cbind( myData, imr ),
##D    subset = selection )
##D summary( heckit00 )
##D 
##D # estimation for y1* > 0
##D selection <- myData$y1
##D # OLS estimation
##D ols1X <- lm( y0 ~ x1, data = myData, subset = selection )
##D summary( ols1X )
##D # heckman type estimation
##D heckit1X <- lm( y0 ~ x1 + IMR1X, data = cbind( myData, imr ),
##D    subset = selection )
##D summary( heckit1X )
##D 
##D # estimation for y1* <= 0
##D selection <- !myData$y1
##D # OLS estimation
##D ols0X <- lm( y0 ~ x1, data = myData, subset = selection )
##D summary( ols0X )
##D # heckman type estimation
##D heckit0X <- lm( y0 ~ x1 + IMR0X, data = cbind( myData, imr ),
##D    subset = selection )
##D summary( heckit0X )
##D 
##D # estimation for y2* > 0
##D selection <- myData$y2
##D # OLS estimation
##D olsX1 <- lm( y0 ~ x1, data = myData, subset = selection )
##D summary( olsX1 )
##D # heckman type estimation
##D heckitX1 <- lm( y0 ~ x1 + IMRX1, data = cbind( myData, imr ),
##D    subset = selection )
##D summary( heckitX1 )
##D 
##D # estimation for y2* <= 0
##D selection <- !myData$y2
##D # OLS estimation
##D olsX0 <- lm( y0 ~ x1, data = myData, subset = selection )
##D summary( olsX0 )
##D # heckman type estimation
##D heckitX0 <- lm( y0 ~ x1 + IMRX0, data = cbind( myData, imr ),
##D    subset = selection )
##D summary( heckitX0 )
## End(Not run)



